#!/bin/bash

#
# Script to validate a SHA1 hash on a file
# Copyright (c)2011, Akamai Haole, LLC
#
# Usage: verifySHA1 <hash> <file>
#

# Executable paths
AWK=/usr/bin/awk
OPENSSL=/opt/local/bin/openssl

# Parameter sanity check
if [ "${1}x" == "x" -o "${2}x" == "x" ]; then
&nbsp;&nbsp;&nbsp;echo ""
&nbsp;&nbsp;&nbsp;echo "Usage: ${0} <hash> <file>"
&nbsp;&nbsp;&nbsp;echo ""
&nbsp;&nbsp;&nbsp;exit
fi

# File existence sanity check
if [ ! -f "${2}" ]; then
&nbsp;&nbsp;&nbsp;echo ""
&nbsp;&nbsp;&nbsp;echo "ERROR: File (${2}) does not exist!"
&nbsp;&nbsp;&nbsp;echo ""
&nbsp;&nbsp;&nbsp;exit
fi

# Calculate SHA1 hash value and trim it
SHA1_HASH_VALUE=`${OPENSSL} sha1 ${2} | ${AWK} 'BEGIN {FS="="}; {gsub(/ /,"",$2); print $2}'`

# File information
echo ""
echo "File path: ${2}"
echo "Calculated SHA1 hash: ${SHA1_HASH_VALUE}"
echo ""

# Test with the SHA1 hash that was passed in
if [ "${SHA1_HASH_VALUE}x" != "${1}x" ]; then
&nbsp;&nbsp;&nbsp;echo "Hash comparison fails!"
else
&nbsp;&nbsp;&nbsp;echo "Hash comparison matches."
fi

echo ""

# End of script